==> quesadilla_runners-0.3.0.tar.gz: quesadilla_runners-0.3.0/README.md <==
<!-- `quesadilla` - an elegant background task queue for the more civilized age
Copyright (C) 2024 Artur Ciesielski <artur.ciesielski@gmail.com>

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>. -->

[![pipeline status](https://gitlab.com/arcanery/python/quesadilla/quesadilla/badges/main/pipeline.svg)](https://gitlab.com/arcanery/python/quesadilla/quesadilla/-/commits/main)
[![coverage report](https://gitlab.com/arcanery/python/quesadilla/quesadilla/badges/main/coverage.svg)](https://gitlab.com/arcanery/python/quesadilla/quesadilla/-/commits/main)
[![latest release](https://gitlab.com/arcanery/python/quesadilla/quesadilla-runners/-/badges/release.svg)](https://gitlab.com/arcanery/python/quesadilla/quesadilla-runners/-/releases)

# quesadilla-runners

Runner libraries for `quesadilla`, an elegant background task queue for the more civilized age.

For more information about the project, see [the main project's homepage](https://gitlab.com/arcanery/python/quesadilla/quesadilla).

==> quesadilla_runners-0.5.0.tar.gz: quesadilla_runners-0.5.0/README.md <==
<!-- `quesadilla` - an elegant background task queue for the more civilized age
Copyright (C) 2024 Artur Ciesielski <artur.ciesielski@gmail.com>

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>. -->

[![pipeline status](https://gitlab.com/arcanery/python/quesadilla/runners/badges/main/pipeline.svg)](https://gitlab.com/arcanery/python/quesadilla/runners/-/commits/main)
[![coverage report](https://gitlab.com/arcanery/python/quesadilla/quesadilla/badges/main/coverage.svg)](https://gitlab.com/arcanery/python/quesadilla/quesadilla/-/commits/main)
[![latest release](https://gitlab.com/arcanery/python/quesadilla/runners/-/badges/release.svg)](https://gitlab.com/arcanery/python/quesadilla/runners/-/releases)

# quesadilla-runners

Runner libraries for `quesadilla`, an elegant background task queue for the more civilized age.

For more information about the project, see [the main project's homepage](https://gitlab.com/arcanery/python/quesadilla/quesadilla).
